==> silentbob-2.3.tar.gz: silentbob-2.3/src/init.cxx <==
/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * (c) Oleg Puchinin 2006
 * graycardinalster@gmail.com
 * 
 */ 

#include <head.h>
#include <mod.h>
#include <temp_names.h>

#define SB_IMMUNE_FILE ".silent_bob/silent_bob_immune"
const char * c_ops [] = { "if", "else", "do", "while",
	"switch", "case", "for", "return", NULL };

int editors_init ();

void mk_dirs ()
{
	char m_buf[4096];
	sprintf (m_buf, "%s/.silent_bob", ENV->home_dir);
	mkdir (m_buf, 0700);
	sprintf (m_buf, "%s/.silent_bob/plugins", ENV->home_dir);
	mkdir (m_buf, 0700);
	ENV->home_plugins = strdup (m_buf);
	ENV->shared_plugins = strdup ("/usr/lib/silent_bob/");
}

int sb_init ()
{
	char * sb_immune_path = CNEW (char, 256);
	char * stdout_vbuf;

	stdout_vbuf = CNEW (char, 4096 * 100);
	setvbuf (stdout, stdout_vbuf, _IOFBF, 4096*100);

	ENV = CNEW(env_t, 1);
	memset (ENV, 0, sizeof (env_t));
	
	ENV->d_cops = new EArray(10);
	ENV->d_cops->push ((char **) c_ops);
	ENV->d_depth = 6;
	ENV->sb_flags = 0;

	ENV->d_tags_file = NULL;
	ENV->immune_list = NULL;
	ENV->cgrep_A = 0;
	ENV->cgrep_B = 0;

	ENV->home_dir = getenv ("HOME");
	ENV->tmp_files = CNEW (char, strlen (ENV->home_dir) + strlen (TMPNAME_FILES) + 20);
	sprintf (ENV->tmp_files, "%s/.silent_bob/%s", ENV->home_dir, TMPNAME_FILES);
	ENV->tmp_tags = CNEW (char, strlen (ENV->home_dir) + strlen (TMPNAME_TAGS) + 20);
	sprintf (ENV->tmp_tags, "%s/.silent_bob/%s", ENV->home_dir, TMPNAME_TAGS);
	ENV->debug_file =  (char *) "/tmp/silent_bob.log";

	mk_dirs ();
	sprintf (sb_immune_path, "%s/.silent_bob/%s", getenv ("HOME"), SB_IMMUNE_FILE);

	ENV->immune_list = new EArray;
	ENV->immune_list->from_file (sb_immune_path);
	ENV->immune_list->foreach ((Dfunc_t) chomp);
	ENV->full_list = new EArray;
	
	ENV->d_stream_dbg = fopen ("/dev/null", "w");	
	ENV->max_proc = 1;
	ENV->nproc = 1;
	ENV->proc_list = new DJobs;
	ENV->listOptions = new EList;
	ENV->language = strdup ("C");

	//modding_init ();
	//editors_init ();

	return 0;
}

==> silentbob-2.4.2.tar.gz: silentbob-2.4.2/src/init.cxx <==
/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * (c) Oleg Puchinin 2006
 * graycardinalster@gmail.com
 * 
 */ 

#include <head.h>
#include <mod.h>
#include <temp_names.h>

#define SB_IMMUNE_FILE ".silent_bob/silent_bob_immune"
const char * c_ops [] = { "if", "else", "do", "while",
	"switch", "case", "for", "return", NULL };

int editors_init ();

void mk_dirs ()
{
	char m_buf[4096];
	sprintf (m_buf, "%s/.silent_bob", ENV->home_dir);
	mkdir (m_buf, 0700);
	sprintf (m_buf, "%s/.silent_bob/plugins", ENV->home_dir);
	mkdir (m_buf, 0700);
	ENV->home_plugins = strdup (m_buf);
	ENV->shared_plugins = strdup ("/usr/lib/silent_bob/");
}

int sb_init ()
{
	char * sb_immune_path = CNEW (char, 256);
	char * stdout_vbuf;

	stdout_vbuf = CNEW (char, 4096 * 100);
	setvbuf (stdout, stdout_vbuf, _IOFBF, 4096*100);

	ENV = CNEW(env_t, 1);
	memset (ENV, 0, sizeof (env_t));
	
	ENV->d_cops = new EArray(10);
	ENV->d_cops->push ((char **) c_ops);
	ENV->d_depth = 6;
	ENV->sb_flags = 0;

	ENV->d_tags_file = NULL;
	ENV->immune_list = NULL;
	ENV->cgrep_A = 0;
	ENV->cgrep_B = 0;

	ENV->home_dir = getenv ("HOME");
	ENV->tmp_files = CNEW (char, strlen (ENV->home_dir) + strlen (TMPNAME_FILES) + 20);
	sprintf (ENV->tmp_files, "%s/.silent_bob/%s", ENV->home_dir, TMPNAME_FILES);
	ENV->tmp_tags = CNEW (char, strlen (ENV->home_dir) + strlen (TMPNAME_TAGS) + 20);
	sprintf (ENV->tmp_tags, "%s/.silent_bob/%s", ENV->home_dir, TMPNAME_TAGS);
	ENV->debug_file =  (char *) "/tmp/silent_bob.log";

	mk_dirs ();
	sprintf (sb_immune_path, "%s/.silent_bob/%s", getenv ("HOME"), SB_IMMUNE_FILE);

	ENV->immune_list = new EArray;
	ENV->immune_list->from_file (sb_immune_path);
	ENV->immune_list->foreach ((Dfunc_t) chomp);
	ENV->full_list = new EArray;
	
	ENV->d_stream_dbg = fopen ("/dev/null", "w");	
	ENV->max_proc = 1;
	ENV->nproc = 1;
	ENV->proc_list = new DJobs;
	ENV->listOptions = new EList;
	ENV->language = strdup ("ALL");

	//modding_init ();
	//editors_init ();

	return 0;
}
